/*++

// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF
// ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO
// THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
// PARTICULAR PURPOSE.
//
// Copyright (c) Microsoft Corporation. All rights reserved


Module Name:

    Defines.h

Abstract:

    This module contains the common definitions used throughout the 
    project

--*/

#pragma once

enum SensorType {Accelerometer, AmbientLight, SwitchArrayLeft, SwitchArrayRight, SensorNone };

#define NUMBER_OF_SENSORS   4
#define READ_BUFFER_SIZE    1024
#define PENDING_READ_COUNT  2   // If we are missing asynchronous read results, increase this number


/* Limits for HID report structures */
#define SIZE_HEADER_ALIGN_ARRAY 2
#define SIZE_CHAR_DATA_ARRAY   32
#define SIZE_WORD_DATA_ARRAY   16
#define SIZE_DWORD_DATA_ARRAY  8
#define SIZE_FLOAT_DATA_ARRAY  8
#define SIZE_PAD_DATA_ARRAY    8
#define SIZE_PRINTED_GUID	   64

#define SIZE_SIMPLE_DATA_ARRAY 7
#define SIZE_SIMPLE_PAD_ARRAY  48

/* Definitions  for HID Read/Write Report structures*/
typedef struct _OUT_STRUCT {
    BYTE    device_id;
	BYTE    sensor_id;
	BYTE    command_or_index;
	BYTE    status;	
	GUID    report_id;
	DWORD   prop_variant;

    union
	{
      BYTE  char_data[SIZE_CHAR_DATA_ARRAY];
      WORD  word_data[SIZE_WORD_DATA_ARRAY];
      DWORD dword_data[SIZE_DWORD_DATA_ARRAY];
	  FLOAT float_data[SIZE_FLOAT_DATA_ARRAY];
      GUID  GUID_data;
      PROPERTYKEY PROPERTYKEY_data;
	};
	
	BYTE padding[SIZE_PAD_DATA_ARRAY]; // pad out to 64-bytes
	
} OUT_STRUCT;
    
#ifdef _ORIGINAL_
typedef struct _IN_STRUCT {
    BYTE    device_id;
	BYTE    sensor_id;
	BYTE    command_or_index;
	BYTE    status;
	GUID    report_id;
	DWORD   prop_variant;
	
	union
	{
      BYTE  char_data[SIZE_CHAR_DATA_ARRAY];
      WORD  word_data[SIZE_WORD_DATA_ARRAY];
      DWORD dword_data[SIZE_DWORD_DATA_ARRAY];
	  FLOAT float_data[SIZE_FLOAT_DATA_ARRAY];
      GUID  GUID_data;
      PROPERTYKEY PROPERTYKEY_data;
	};
	
    BYTE padding[SIZE_PAD_DATA_ARRAY]; // pad out to 64-bytes
	
} IN_STRUCT;
#else
typedef struct _IN_STRUCT {
	BYTE    sensor_id;
	BYTE    byte_data[SIZE_SIMPLE_DATA_ARRAY];
    BYTE    padding[SIZE_SIMPLE_PAD_ARRAY]; // pad out to 64-bytes
	
} IN_STRUCT;
#endif

#define DEVICE_PROTOCOL_VALUE                           L"Sensor Protocol ver 1.00"
#define DEVICE_FIRMWARE_VERSION_VALUE                   L"1.0.0.0"
#define DEVICE_POWER_LEVEL_VALUE                        100
#define DEVICE_MODEL_VALUE                              L"Sensor"
#define DEVICE_FRIENDLY_NAME_VALUE                      L"Sensor"
#define DEVICE_MANUFACTURER_VALUE                       L"DevDrv"
#define DEVICE_SERIAL_NUMBER_VALUE                      L"Sample"
#define DEVICE_SUPPORTS_NONCONSUMABLE_VALUE             TRUE

#define SENSOR_DEVICE_ID                                L"Sensor"
#define SENSOR_DEVICE_FRIENDLY_NAME                     L"Sensor"
#define SENSOR_DEVICE_DESCRIPTION                       L"Sensor"

//// {C5B0A174-615E-4121-9CED-F7568D39C861}
//DEFINE_GUID(SENSOR_DEVICE_GUID,                         0XC5B0A174, 0X615E, 0X4121, 0X9C, 0XED, 0XF7, 0X56, 0X8D, 0X39, 0XC8, 0X61);
//DEFINE_PROPERTYKEY(SENSOR_DEVICE_KEY,                   0XC5B0A174, 0X615E, 0X4121, 0X9C, 0XED, 0XF7, 0X56, 0X8D, 0X39, 0XC8, 0X61, 0);

// {2463ED22-1261-49bb-AAF4-CED1DB4A1137}
DEFINE_GUID(SENSOR_DEVICE_GUID,							0x2463ed22, 0x1261, 0x49bb, 0xaa, 0xf4, 0xce, 0xd1, 0xdb, 0x4a, 0x11, 0x37);
DEFINE_PROPERTYKEY(SENSOR_DEVICE_KEY,					0x2463ed22, 0x1261, 0x49bb, 0xaa, 0xf4, 0xce, 0xd1, 0xdb, 0x4a, 0x11, 0x37, 0);

#define SENSOR_ACCELEROMETER_ID                         L"Accelerometer"
#define SENSOR_ACCELEROMETER_FRIENDLY_NAME              L"Accelerometer Sensor"
#define SENSOR_ACCELEROMETER_DESCRIPTION                L"Accelerometer Sensor"

#define SENSOR_AMBIENT_LIGHT_ID                         L"Ambient Light"
#define SENSOR_LIGHT_FRIENDLY_NAME                      L"Ambient Light Sensor"
#define SENSOR_LIGHT_DESCRIPTION                        L"Ambient Light Sensor"

#define SENSOR_SWITCH_ARRAY_LEFT_ID                     L"Switch Array Left"
#define SENSOR_SWITCH_ARRAY_LEFT_FRIENDLY_NAME          L"Left Switch Array Sensor"
#define SENSOR_SWITCH_ARRAY_LEFT_DESCRIPTION            L"Left Switch Array Sensor"

#define SENSOR_SWITCH_ARRAY_RIGHT_ID                    L"Switch Array Right"
#define SENSOR_SWITCH_ARRAY_RIGHT_FRIENDLY_NAME         L"Right Switch Array Sensor"
#define SENSOR_SWITCH_ARRAY_RIGHT_DESCRIPTION           L"Right Switch Array Sensor"

//// {7F8383EC-D3EC-495C-A8CF-B8BBE85C2920}
//DEFINE_PROPERTYKEY(SENSOR_PROPERTY_DEVICE_ID,           0X7F8383EC, 0XD3EC, 0X495C, 0XA8, 0XCF, 0XB8, 0XBB, 0XE8, 0X5C, 0X29, 0X20, 17); //[ VT_LPWSTR]

// {E76F453C-4D4F-4f2b-9443-F0A38C4518FC}
DEFINE_PROPERTYKEY(SENSOR_PROPERTY_DEVICE_ID,           0xe76f453c, 0x4d4f, 0x4f2b, 0x94, 0x43, 0xf0, 0xa3, 0x8c, 0x45, 0x18, 0xfc, 17);

// Default Values 
#define DEFAULT_ACCELERATION_G                          1.0F
#define DEFAULT_CHANGE_SENSITIVITY                      0
#define DEFAULT_LIGHT_LEVEL_LUX                         2.0F
#define DEFAULT_BOOLEAN_SWITCH_ARRAY_STATE              0
#define DEFAULT_MIN_REPORT_INTERVAL                     16
#define AWAKE_CURRENT_REPORT_INTERVAL                   100
#define SLEEP_CURRENT_REPORT_INTERVAL                   0
#define MIN_CHANGE_SENSITIVITY                          0.0F
#define MAX_CHANGE_SENSITIVITY                          100.0F