/*++

// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF
// ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO
// THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
// PARTICULAR PURPOSE.
//
// Copyright (c) Microsoft Corporation. All rights reserved

Module Name:

    Device.h

Abstract:

    This module contains the type definitions for the Badge Board driver
    device callback class.

--*/

#pragma once

#include "SensorDriver.h"

class ATL_NO_VTABLE CMyDevice :
    public CComObjectRootEx<CComMultiThreadModel>,
    public IPnpCallback,
    public IPnpCallbackHardware,
    public IFileCallbackCleanup
{
public:
    ~CMyDevice();

    DECLARE_NOT_AGGREGATABLE(CMyDevice)

    BEGIN_COM_MAP(CMyDevice)
        COM_INTERFACE_ENTRY(IPnpCallback)
        COM_INTERFACE_ENTRY(IPnpCallbackHardware)
        COM_INTERFACE_ENTRY(IFileCallbackCleanup)
    END_COM_MAP()

protected:
    
    CMyDevice();
    HRESULT ConfigureQueue();

// COM Interface methods
public:

    //
    // IPnpCallbackHardware
    //
    STDMETHOD_ (HRESULT, OnPrepareHardware)(__in IWDFDevice* pWdfDevice);
    STDMETHOD_ (HRESULT, OnReleaseHardware)(__in IWDFDevice* pWdfDevice);

    //
    // IPnpCallback
    //
    STDMETHOD (OnD0Entry)( __in IWDFDevice* pWdfDevice,  __in WDF_POWER_DEVICE_STATE previousState);
    STDMETHOD (OnD0Exit)( __in IWDFDevice* pWdfDevice,  __in WDF_POWER_DEVICE_STATE newState);
    STDMETHOD_ (VOID, OnSurpriseRemoval)( __in IWDFDevice* pWdfDevice);
    STDMETHOD_ (HRESULT, OnQueryRemove)(  __in IWDFDevice* pWdfDevice);
    STDMETHOD_ (HRESULT, OnQueryStop)( __in IWDFDevice* pWdfDevice);

    //
    // IFileCallbackCleanup
    //
    STDMETHOD_ (VOID, OnCleanupFile)(__in IWDFFile *pWdfFile);

public:

    // The factory method used to create an instance of this device
    static HRESULT CreateInstance(__in IWDFDriver* pDriver, __in IWDFDeviceInitialize*  pDeviceInit);

    HRESULT ProcessIoControl(__in IWDFIoQueue*     pQueue,
                             __in IWDFIoRequest*   pRequest,
                             __in ULONG            ControlCode,
                                  SIZE_T           InputBufferSizeInBytes,
                                  SIZE_T           OutputBufferSizeInBytes,
                                  DWORD*           pcbWritten);
private:

    CComPtr<IWDFDevice>                 m_pWdfDevice;
    CComObject<CBadgeSensorDriver>*     m_pBadgeSensorDriver;
};