/*++
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF
// ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO
// THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
// PARTICULAR PURPOSE.
//
// Copyright (c) Microsoft Corporation. All rights reserved


Module Name:
    BadgeSensorDriver.h

Abstract:
    Defines the CBadgeSensorDriver container class

--*/

#pragma once

#include "SensorDDI.h"

class CBadgeSensorDriver :
    public CComObjectRoot
{
public:
    CBadgeSensorDriver();
    virtual ~CBadgeSensorDriver();

    DECLARE_NOT_AGGREGATABLE(CBadgeSensorDriver)

    BEGIN_COM_MAP(CBadgeSensorDriver)
        
    END_COM_MAP()

    HRESULT Initialize(__in IWDFDevice* pWdfDevice);
    void    Uninitialize();
    
    HRESULT Start();
    HRESULT Stop();

    void    CleanupFile(__in IWDFFile *pWdfFile);
    HRESULT ProcessIoControl(__in IWDFIoRequest*   pRequest);
       
private:

    // Private Methods

    HRESULT InitializeClassExtension();
    BOOL    IsInitialized(void) const { return m_fBadgeSensorDriverInitialized; }
   
    //Methods that call into Class Extension
    HRESULT PostDataEvent(__in LPWSTR objectId, IPortableDeviceValues *pValues);
       
    // Thread Process that fires data events
    static DWORD WINAPI _SensorEventThreadProc(__in LPVOID pvData);

    // Helper functions to activate/deactivate thread
    VOID    Activate();
    VOID    DeActivate();
    BOOL    IsActive()                  { return m_fThreadActive; }
    HANDLE  GetSensorEventHandle(VOID)  { return m_hSensorEvent; }
      
    // Private Data Members
    CComPtr<IWDFDevice>             m_pWdfDevice;
    CComPtr<ISensorClassExtension>  m_pClassExtension;
    CComObject<CSensorDDI>*         m_pSensorDDI;


    mutable CComAutoCriticalSection m_CriticalSection;
    BOOL                            m_fBadgeSensorDriverInitialized;
    HANDLE                          m_hSensorEvent;
    HANDLE                          m_hBadgeSensorEventingThread;       // Thread handle for raising data events
    BOOL                            m_fThreadActive;                    // Flag denoting that driver thread is active
};

typedef CAtlMap< SensorType, CComBSTR > SENSOR_MAP;
extern SENSOR_MAP g_SupportedSensors;