/*++

// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF
// ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO
// THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
// PARTICULAR PURPOSE.
//
// Copyright (c) Microsoft Corporation. All rights reserved

Module Name:

    Internal.h

Abstract:

    This module contains the local type definitions for the Badge Board 
    driver sample.

--*/

#pragma once

#include <windows.h>
#include <atlbase.h>
#include <atlcom.h>
#include <atlcoll.h>
#include <atlstr.h>
#include <atlcomtime.h>

__user_driver;  // Macro letting the compiler know this is not a kernel driver (this will help surpress needless warnings)

// Common WPD and WUDF headers
#include <devioctl.h>
#include <initguid.h>
#include <propkeydef.h>
#include <propvarutil.h>
#include "PortableDeviceTypes.h"
#include "PortableDeviceClassExtension.h"
#include "PortableDevice.h"

// Headers for Sensor specific defines and WpdCommands
#include "Sensors.h"
#include <SensorsClassExtension.h>
#include "sensor2.h"

///////////////////////////////////////////////////////////////////
// Common macro expansions that are used throughout the project
#define SAFE_RELEASE(p)     {if ((p)) { (p)->Release(); (p) = NULL; }}
#define ARRAY_SIZE(x)       (sizeof(x) / sizeof(x[0]))

///////////////////////////////////////////////////////////////////
// TRACING SUPPORT
//
// Define the tracing flags.
//

// Tracing Information
//#define MYDRIVER_TRACING_ID L"Microsoft\\Sensor\\SensorsBadgeDriver"
#define MYDRIVER_TRACING_ID L"DevDrv\\Sensor\\SensorsDriver"

//
// Define the tracing flags.
//
// Choose a different trace control GUID
//

//#define WPP_CONTROL_GUIDS   WPP_DEFINE_CONTROL_GUID( SensorsBadgeDriverTraceControl, (8B989B23,1771,4BB1,A4A6,4D08A1817CFD), \
//                                                      WPP_DEFINE_BIT(MYDRIVER_ALL_INFO) )

#define WPP_CONTROL_GUIDS   WPP_DEFINE_CONTROL_GUID( SensorsDriverTraceControl, (24939BB0,DBC1,4c4a,9483,12ADC49B2D12), \
                                                      WPP_DEFINE_BIT(MYDRIVER_ALL_INFO) )

#define WPP_FLAG_LEVEL_LOGGER(flag, level)      WPP_LEVEL_LOGGER(flag)

#define WPP_FLAG_LEVEL_ENABLED(flag, level)    ( WPP_LEVEL_ENABLED(flag) && \
                                                 WPP_CONTROL(WPP_BIT_ ## flag).Level >= level )

//
// This comment block is scanned by the trace preprocessor to define our
// Trace function.
//
// begin_wpp config
// FUNC Trace{FLAG=MYDRIVER_ALL_INFO}(LEVEL, MSG, ...);
// end_wpp
//
